( cd usr/lib ; rm -rf libgif.a )
( cd usr/lib ; ln -sf libungif.a libgif.a )
( cd usr/lib ; rm -rf libgif.so )
( cd usr/lib ; ln -sf libgif.so.4 libgif.so )
( cd usr/lib ; rm -rf libgif.so.4 )
( cd usr/lib ; ln -sf libgif.so.4.1.0 libgif.so.4 )
( cd usr/lib ; rm -rf libgif.so.4.1.0 )
( cd usr/lib ; ln -sf libungif.so.4.1.0 libgif.so.4.1.0 )
( cd usr/lib ; rm -rf libungif.so )
( cd usr/lib ; ln -sf libungif.so.4.1.0 libungif.so )
( cd usr/lib ; rm -rf libungif.so.4 )
( cd usr/lib ; ln -sf libungif.so.4.1.0 libungif.so.4 )
